@@ -405,8 +405,8 @@ class GitConfiguration(SetupTask):
     def read_git_config(self, setting):
         "Reads current git config setting"
         result = run(f"git config --get {setting}", shell=True, check=True, 
-                capture_output=True, text=True
-        return result.stdout.strip())
+                capture_output=True, text=True)
+        return result.stdout.strip()
 
     def get_expected_git_config(self):
         """Returns a dict containing expected git configuration settings.
